@@ -2,10 +2,10 @@
 """Contains helpers for template."""
 
 import uuid
-from math import sqrt
 from typing import Dict, List, Tuple, Union
 
 import pdfrw
+from reportlab.pdfbase.pdfmetrics import stringWidth
 
 from ..middleware.element import Element as ElementMiddleware
 from ..middleware.element import ElementType
@@ -274,40 +274,44 @@ class Template:
     @staticmethod
     def get_draw_checkbox_radio_coordinates_v2(
         element: "pdfrw.PdfDict",
-        font_size: Union[float, int],
+        element_middleware: "ElementMiddleware",
     ) -> Tuple[Union[float, int], Union[float, int]]:
         """Returns coordinates to draw at given a PDF form checkbox/radio element."""
 
-        side = font_size * 96 / 72
-        c_half_width = (
+        string_height = element_middleware.font_size * 96 / 72
+        width_mid_point = (
             float(element[TemplateCoreConstants().annotation_rectangle_key][0])
             + float(element[TemplateCoreConstants().annotation_rectangle_key][2])
         ) / 2
-        c_half_height = (
+        height_mid_point = (
             float(element[TemplateCoreConstants().annotation_rectangle_key][1])
             + float(element[TemplateCoreConstants().annotation_rectangle_key][3])
         ) / 2
 
         return (
-            (c_half_width - side / 2 + c_half_width) / 2,
-            (c_half_height - side / 2 + c_half_height) / 2,
+            width_mid_point
+            - stringWidth(
+                element_middleware.value,
+                element_middleware.font,
+                element_middleware.font_size,
+            )
+            / 2,
+            (height_mid_point - string_height / 2 + height_mid_point) / 2,
         )
 
     @staticmethod
     def get_draw_text_coordinates(
-        element: "pdfrw.PdfDict",
+        element: "pdfrw.PdfDict", element_middleware: "ElementMiddleware"
     ) -> Tuple[Union[float, int], Union[float, int]]:
         """Returns coordinates to draw text at given a PDF form text element."""
 
-        return (
-            float(element[TemplateCoreConstants().annotation_rectangle_key][0]),
-            (
-                float(element[TemplateCoreConstants().annotation_rectangle_key][1])
-                + float(element[TemplateCoreConstants().annotation_rectangle_key][3])
-            )
-            / 2
-            - 2,
-        )
+        x = float(element[TemplateCoreConstants().annotation_rectangle_key][0])
+        y = (
+            float(element[TemplateCoreConstants().annotation_rectangle_key][1])
+            + float(element[TemplateCoreConstants().annotation_rectangle_key][3])
+        ) / 2 - 2
+
+        return x, y
 
     @staticmethod
     def get_text_field_max_length(element: "pdfrw.PdfDict") -> Union[int, None]:
@@ -351,46 +355,100 @@ class Template:
         return Utils().generate_stream(pdf_file)
 
     @staticmethod
-    def font_size_for_text_field_with_max_length(
-        element: "pdfrw.PdfDict",
-        max_length: int,
-    ) -> float:
-        """Calculates the font size for a text field with max length."""
+    def get_character_x_paddings(
+        element: "pdfrw.PdfDict", element_middleware: "ElementMiddleware"
+    ) -> List[float]:
+        """Returns paddings between characters for combed text fields."""
 
-        area = abs(
+        rect_width = abs(
             float(element[TemplateCoreConstants().annotation_rectangle_key][0])
             - float(element[TemplateCoreConstants().annotation_rectangle_key][2])
-        ) * abs(
-            float(element[TemplateCoreConstants().annotation_rectangle_key][1])
-            - float(element[TemplateCoreConstants().annotation_rectangle_key][3])
         )
+        length = min(len(element_middleware.value or ""), element_middleware.max_length)
 
-        return sqrt(area / max_length)
+        char_rect_width = rect_width / element_middleware.max_length
+
+        result = []
+
+        current_x = 0
+        for char in (element_middleware.value or "")[:length]:
+            current_mid_point = current_x + char_rect_width / 2
+            result.append(
+                current_mid_point
+                - stringWidth(
+                    char, element_middleware.font, element_middleware.font_size
+                )
+                / 2
+            )
+            current_x += char_rect_width
+
+        return result
 
     @staticmethod
-    def get_draw_text_with_max_length_coordinates(
+    def get_draw_text_coordinates_v2(
         element: "pdfrw.PdfDict", element_middleware: "ElementMiddleware"
     ) -> Tuple[Union[float, int], Union[float, int]]:
-        """Returns coordinates to draw at given a PDF form text field with max length."""
+        """Returns coordinates to draw text at given a PDF form text element."""
 
-        length = min(len(element_middleware.value), element_middleware.max_length)
-        width = element_middleware.font_size * length * 96 / 72
-        height = element_middleware.font_size * 96 / 72
-        c_half_width = (
-            float(element[TemplateCoreConstants().annotation_rectangle_key][0])
-            + float(element[TemplateCoreConstants().annotation_rectangle_key][2])
-        ) / 2
-        c_half_height = (
+        length = (
+            min(len(element_middleware.value or ""), element_middleware.max_length)
+            if element_middleware.max_length is not None
+            else len(element_middleware.value or "")
+        )
+
+        alignment = (
+            element[TemplateCoreConstants().text_field_alignment_identifier] or 0
+        )
+        x = float(element[TemplateCoreConstants().annotation_rectangle_key][0])
+
+        if int(alignment) != 0:
+            width_mid_point = (
+                float(element[TemplateCoreConstants().annotation_rectangle_key][0])
+                + float(element[TemplateCoreConstants().annotation_rectangle_key][2])
+            ) / 2
+            string_width = stringWidth(
+                (element_middleware.value or "")[:length],
+                element_middleware.font,
+                element_middleware.font_size,
+            )
+            if element_middleware.comb is True and length:
+                string_width = element_middleware.character_paddings[-1] + stringWidth(
+                    element_middleware.value[:length][-1],
+                    element_middleware.font,
+                    element_middleware.font_size,
+                )
+
+            if int(alignment) == 1:
+                x = width_mid_point - string_width / 2
+            elif int(alignment) == 2:
+                x = (
+                    float(element[TemplateCoreConstants().annotation_rectangle_key][2])
+                    - string_width
+                )
+
+        string_height = element_middleware.font_size * 96 / 72
+        height_mid_point = (
             float(element[TemplateCoreConstants().annotation_rectangle_key][1])
             + float(element[TemplateCoreConstants().annotation_rectangle_key][3])
         ) / 2
 
         return (
-            (c_half_width - width / 2 + c_half_width) / 2
+            x
             - (
-                element_middleware.font_size * 0.5 * 96 / 72
-                if (element_middleware.comb is True and length % 2 == 0)
+                element_middleware.character_paddings[0]
+                + stringWidth(
+                    element_middleware.value[:1],
+                    element_middleware.font,
+                    element_middleware.font_size,
+                )
+                / 2
+                if (
+                    element_middleware.comb is True
+                    and length != 0
+                    and length % 2 == 0
+                    and int(alignment) == 1
+                )
                 else 0
             ),
-            (c_half_height - height / 2 + c_half_height) / 2,
+            (height_mid_point - string_height / 2 + height_mid_point) / 2,
         )
