@@ -29,7 +29,7 @@ class FileAdapter:
             if not os.path.isfile(fp_or_f_obj_or_stream):
                 return None
 
-            with open(fp_or_f_obj_or_stream, "rb+") as f:
-                return f.read()
+            with open(fp_or_f_obj_or_stream, "rb+") as _file:
+                return _file.read()
 
         return None
